@@ -1,3 +1,9 @@
+if($] < 5.008) {
+	require Test::More;
+	Test::More::plan(skip_all =>
+		"pure Perl Lexical::SealRequireHints can't work on this perl");
+}
+
 require XSLoader;
 
 my $orig_load = \&XSLoader::load;
